@@ -1,11 +1,17 @@
 #include <QContactManager>
 #include "contactsthreadworker.h"
+#include "k9call.h"
 
 using namespace QtMobility;
 
-ContactsThreadWorker::ContactsThreadWorker()
+ContactsThreadWorker::ContactsThreadWorker(k9call* k)
     : QThread(0)
 {
+	// Setup connections
+	connect(this, SIGNAL(updateContacts(QList<QtMobility::QContact>)), 
+	        k, SLOT(updateContacts(QList<QtMobility::QContact>)), Qt::QueuedConnection);
+
+	// Setup thread
 	this->start(IdlePriority);
 	this->moveToThread(this);
 }
@@ -18,7 +24,7 @@ void ContactsThreadWorker::run()
 void ContactsThreadWorker::syncContacts()
 {
 	qDebug() << "Sync Contacts ThreadId " << (int)QThread::currentThreadId();
-    QContactManager m;
+  QContactManager m;
 	QContactFetchHint hint;
 	QContactFetchHint::OptimizationHints optimizations = 0;
 	optimizations |= QContactFetchHint::NoBinaryBlobs;
