@@ -5,12 +5,14 @@
 #include <QContact>
 #include <QContactId>
 
+class k9call;
+
 class ContactsThreadWorker : public QThread
 {
     Q_OBJECT
 
 public:
-    ContactsThreadWorker();
+    ContactsThreadWorker(k9call* k);
     void run();
 
 signals:
