@@ -25,14 +25,13 @@ public slots:
     void updateQuery();
 	void nextContact();
 	void nextPhoneNumber();
+	void syncContacts();
     void updateContacts(QList<QtMobility::QContact> contacts);
 	void openSettings();
 	void closeSettings();
-	
-signals:
-	void syncContacts();
 
-public:
+public:	
+
     explicit k9call(QWidget *parent = 0);
 
 private:
@@ -60,8 +59,8 @@ private:
 	QList<QContactPhoneNumber> m_PhoneNumbers;
 	QList<QContactPhoneNumber>::const_iterator m_PhoneNumbersItr;
 
-	QContactManager m_Manager;
-	ContactsThreadWorker m_ContactWorker;
+	QContactManager* m_Manager;
+	ContactsThreadWorker* m_ContactWorker;
 	bool m_Initialized;
 	
 	QString m_SearchString;
